==> xcsoar-7.21.tar.xz: xcsoar-7.21/src/Android/Bitmap.hpp <==
/*
Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2021 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#ifndef XCSOAR_ANDROID_BITMAP_HPP
#define XCSOAR_ANDROID_BITMAP_HPP

#include <jni.h>

#include <cassert>

class AndroidBitmap {
  static jmethodID recycle_method;
  static jmethodID getWidth_method, getHeight_method;

public:
  static void Initialise(JNIEnv *env);
  static void Deinitialise(JNIEnv *env) {}

  [[gnu::pure]]
  static void Recycle(JNIEnv *env, jobject bitmap) {
    assert(env != nullptr);
    assert(bitmap != nullptr);

    return env->CallVoidMethod(bitmap, recycle_method);
  }

  [[gnu::pure]]
  static unsigned GetWidth(JNIEnv *env, jobject bitmap) {
    assert(env != nullptr);
    assert(bitmap != nullptr);

    return env->CallIntMethod(bitmap, getWidth_method);
  }

  [[gnu::pure]]
  static unsigned GetHeight(JNIEnv *env, jobject bitmap) {
    assert(env != nullptr);
    assert(bitmap != nullptr);

    return env->CallIntMethod(bitmap, getHeight_method);
  }
};

#endif

==> xcsoar-7.28.tar.xz: xcsoar-7.28/src/Android/Bitmap.hpp <==
/*
Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2022 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#pragma once

#include <jni.h>
#include <cassert>

class AndroidBitmap {
  static jmethodID recycle_method;
  static jmethodID getWidth_method, getHeight_method;

public:
  static void Initialise(JNIEnv *env);
  static void Deinitialise([[maybe_unused]] JNIEnv *env) {}

  [[gnu::pure]]
  static void Recycle(JNIEnv *env, jobject bitmap) {
    assert(env != nullptr);
    assert(bitmap != nullptr);

    return env->CallVoidMethod(bitmap, recycle_method);
  }

  [[gnu::pure]]
  static unsigned GetWidth(JNIEnv *env, jobject bitmap) {
    assert(env != nullptr);
    assert(bitmap != nullptr);

    return env->CallIntMethod(bitmap, getWidth_method);
  }

  [[gnu::pure]]
  static unsigned GetHeight(JNIEnv *env, jobject bitmap) {
    assert(env != nullptr);
    assert(bitmap != nullptr);

    return env->CallIntMethod(bitmap, getHeight_method);
  }
};
